==> Hefesto-0.1.0.tar.gz: Hefesto-0.1.0/Hefesto/template.py <==

class Template:

  template_model = dict(

    Birth_date = dict(
      processURI = "http://purl.obolibrary.org/obo/NCIT_C142470",
      outputURI = "http://www.ebi.ac.uk/efo/EFO_0006921",
      inputURI = None,
      attributeURI = "http://purl.obolibrary.org/obo/NCIT_C68615",
      valueAttributeIRI = None,
      valueOutputDate = None,
      valueOutputNumber = None,
      valueOutputString = None,
      valueInputString = None,
      pid = None,
      chronoid = None
    ),


  Sex = dict( 
    processURI = "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI = "http://purl.obolibrary.org/obo/NCIT_C103159",
    inputURI = None,
    attributeURI = "http://purl.obolibrary.org/obo/NCIT_C28421",
    valueAttributeIRI = None,
    valueOutputDate = None,
    valueOutputNumber = None,
    valueOutputString = None,
    valueInputString = None,
    pid = None,
    chronoid = None,
  ),


  Patient_status = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C103159",
    inputURI = None,
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C166244",
    valueAttributeIRI = None,
    valueOutputDate = None,
    valueOutputNumber = None,
    valueOutputString = None,
    valueInputString = None,
    pid = None,
    chronoid = None
  ),

  Date_of_death = dict( 
    processURI= "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C103159",
    inputURI = None,
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C70810",
    valueAttributeIRI = None,
    valueOutputDate = None,
    valueOutputNumber = None,
    valueOutputString = None,
    valueInputString = None,
    pid = None,
    chronoid = None
  ),

  Care_pathway = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C159705",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C25716",
    inputURI = None,
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C164021",
    valueAttributeIRI = None,
    valueOutputDate = None,
    valueOutputNumber = None,
    valueOutputString = None,
    valueInputString = None,
    pid = None,
    chronoid = None
  ),

  Diagnosis = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C15220",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C103159",
    inputURI = None,
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C25482",
    valueAttributeIRI = None,
    valueOutputDate = None,
    valueOutputNumber = None,
    valueOutputString = None,
    valueInputString = None,
    pid = None,
    chronoid = None
  ),

  Date_of_diagnosis = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI = None,
    inputURI = None,
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C156420",
    valueAttributeIRI = None,
    valueOutputDate = None,
    valueOutputNumber = None,
    valueOutputString = None,
    valueInputString = None,
    pid = None,
    chronoid = None
  ),

  Onset_of_symptoms = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI = None,
    inputURI = None,
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C25279",
    valueAttributeIRI = None,
    valueOutputDate = None,
    valueOutputNumber = None,
    valueOutputString = None,
    valueInputString = None,
    pid = None,
    chronoid = None
  ),

  Phenotype = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C25305",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C125204",
    inputURI = None,
    attributeURI= "http://semanticscience.org/resource/SIO_010056",
    valueAttributeIRI = None,
    valueOutputDate = None,
    valueOutputNumber = None,
    valueOutputString = None,
    valueInputString = None,
    pid = None,
    chronoid = None
  ),

  Genotype_OMIM = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C15709",
    outputURI= "http://edamontology.org/data_1153",
    inputURI = None,
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C17938",
    valueAttributeIRI = None,
    valueOutputDate = None,
    valueOutputNumber = None,
    valueOutputString = None,
    valueInputString = None,
    pid = None,
    chronoid = None
  ),


  Genotype_HGNC = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C15709",
    outputURI= "http://edamontology.org/data_2295",
    inputURI = None,
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C17938",
    valueAttributeIRI = None,
    valueOutputDate = None,
    valueOutputNumber = None,
    valueOutputString = None,
    valueInputString = None,
    pid = None,
    chronoid = None
  ),


  Genotype_HGVS = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C15709",
    outputURI= "http://semanticscience.org/resource/SIO_001388",
    inputURI = None,
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C17938",
    valueAttributeIRI = None,
    valueOutputDate = None,
    valueOutputNumber = None,
    valueOutputString = None,
    valueInputString = None,
    pid = None,
    chronoid = None
  ),

  Consent = dict(
    processURI= "http://purl.obolibrary.org/obo/OBI_0000810",
    outputURI = None,
    inputURI= "http://purl.obolibrary.org/obo/ICO_0000001",
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C25460",
    valueAttributeIRI = None,
    valueOutputDate = None,
    valueOutputNumber = None,
    valueOutputString = None,
    valueInputString = None,
    pid = None,
    chronoid = None
  ),

  Biobanking = dict(
    processURI= "http://purl.obolibrary.org/obo/OMIABIS_0000061",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C19157",
    inputURI= "http://purl.obolibrary.org/obo/OMIABIS_0000000",
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C25429",
    valueAttributeIRI = None,
    valueOutputDate = None,
    valueOutputNumber = None,
    valueOutputString = None,
    valueInputString = None,
    pid = None,
    chronoid = None
  ),

  Disability = dict(
    processURI = None,
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C25338",
    inputURI= "http://purl.obolibrary.org/obo/NCIT_C17048",
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C21007",
    valueAttributeIRI = None,
    valueOutputDate = None,
    valueOutputNumber = None,
    valueOutputString = None,
    valueInputString = None,
    pid = None,
    chronoid = None
  )
  )

==> Hefesto-0.1.7.tar.gz: Hefesto-0.1.7/Hefesto/template.py <==

class Template:

  template_model = dict(

  Birthdate = dict(
    processURI = "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI = "http://www.ebi.ac.uk/efo/EFO_0006921",
    attributeURI = "http://purl.obolibrary.org/obo/NCIT_C68615",
    valueAttributeIRI = None,
    valueOutput = None,
    datatype = "xsd:date",
    startdate = None,
    enddate = None,
    pid = None,
    chronoid = None
  ),


  Sex = dict( 
    processURI = "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI = "http://purl.obolibrary.org/obo/NCIT_C103159",
    attributeURI = "http://purl.obolibrary.org/obo/NCIT_C28421",
    valueAttributeIRI = None,
    valueOutput = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    chronoid = None
  ),


  Status = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C103159",
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C166244",
    valueAttributeIRI = None,
    valueOutput = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    chronoid = None
  ),

  Date_of_death = dict( 
    processURI= "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C103159",
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C70810",
    valueAttributeIRI = None,
    valueOutput = None,
    datatype = "xsd:date",
    startdate = None,
    enddate = None,
    pid = None,
    chronoid = None
  ),

  Care_pathway = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C159705",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C25716",
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C164021",
    valueAttributeIRI = None,
    valueOutput = None,
    datatype = "xsd:date",
    startdate = None,
    enddate = None,
    pid = None,
    chronoid = None
  ),

  Diagnosis = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C15220",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C103159",
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C2991",
    valueAttributeIRI = None,
    valueOutput = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    chronoid = None
  ),

  Date_of_diagnosis = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI = None,
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C156420",
    valueAttributeIRI = None,
    valueOutput = None,
    datatype = "xsd:date",
    startdate = None,
    enddate = None,
    pid = None,
    chronoid = None
  ),

  Date_of_symptoms = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI = None,
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C25279",
    valueAttributeIRI = None,
    valueOutput = None,
    datatype = "xsd:date",
    startdate = None,
    enddate = None,
    pid = None,
    chronoid = None
  ),

  Phenotype = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C25305",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C125204",
    attributeURI= "http://semanticscience.org/resource/SIO_010056",
    valueAttributeIRI = None,
    valueOutput = None,
    datatype = "xsd:date",
    startdate = None,
    enddate = None,
    pid = None,
    chronoid = None
  ),

  Genotype = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C15709",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C17248",
    attributeURI= None,
    valueAttributeIRI = None,
    valueOutput = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    chronoid = None
  ),

  Genotype_OMIM = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C15709",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C17248",
    attributeURI= "http://edamontology.org/data_1153",
    valueAttributeIRI = None,
    valueOutput = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    chronoid = None
  ),

  Genotype_HGNC = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C15709",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C17248",
    attributeURI= "http://edamontology.org/data_2295",
    valueAttributeIRI = None,
    valueOutput = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    chronoid = None
  ),

  Consent = dict(
    processURI= "http://purl.obolibrary.org/obo/OBI_0000810",
    outputURI = None,
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C25460",
    valueAttributeIRI = None,
    valueOutput = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    chronoid = None
  ),

  Biobank = dict(
    processURI= "http://purl.obolibrary.org/obo/OMIABIS_0000061",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C115570",
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C25429",
    valueAttributeIRI = None,
    valueOutput = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    chronoid = None
  ),

  Disability = dict(
    processURI = None,
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C25338",
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C21007",
    valueAttributeIRI = None,
    valueOutput = None,
    datatype = "xsd:float",
    startdate = None,
    enddate = None,
    pid = None,
    chronoid = None
  )
  )
